nidaba.plugins package
======================

Submodules
----------

nidaba.plugins.kraken module
----------------------------

.. automodule:: nidaba.plugins.kraken
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.plugins.leptonica module
-------------------------------

.. automodule:: nidaba.plugins.leptonica
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.plugins.ocropus module
-----------------------------

.. automodule:: nidaba.plugins.ocropus
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.plugins.tesseract module
-------------------------------

.. automodule:: nidaba.plugins.tesseract
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nidaba.plugins
    :members:
    :undoc-members:
    :show-inheritance:
